==> qtjambi-qt3dcore-5.15.3-sources.jar: io/qt/qt3d/core/QStaticPropertyValueRemovedChangeBase.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all static PropertyValueRemoved QSceneChange events</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html">Qt3DCore::QStaticPropertyValueRemovedChangeBase</a></p>
 */
public class QStaticPropertyValueRemovedChangeBase extends io.qt.qt3d.core.QPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#QStaticPropertyValueRemovedChangeBase">Qt3DCore::QStaticPropertyValueRemovedChangeBase::QStaticPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    protected QStaticPropertyValueRemovedChangeBase(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QStaticPropertyValueRemovedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#propertyName">Qt3DCore::QStaticPropertyValueRemovedChangeBase::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyValueRemovedChangeBase::setPropertyName(const char*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(java.lang.String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStaticPropertyValueRemovedChangeBase(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QStaticPropertyValueRemovedChangeBase.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all static PropertyValueRemoved QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html">Qt3DCore::QStaticPropertyValueRemovedChangeBase</a></p>
 */
public class QStaticPropertyValueRemovedChangeBase extends io.qt.qt3d.core.QPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#QStaticPropertyValueRemovedChangeBase">Qt3DCore::QStaticPropertyValueRemovedChangeBase::QStaticPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    protected QStaticPropertyValueRemovedChangeBase(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QStaticPropertyValueRemovedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#propertyName">Qt3DCore::QStaticPropertyValueRemovedChangeBase::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueremovedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyValueRemovedChangeBase::setPropertyName(const char*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(java.lang.String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStaticPropertyValueRemovedChangeBase(QPrivateConstructor p) { super(p); } 
    
}
